@@ -1,6 +1,7 @@
 package Win32::EventLog::Carp;
 
 use strict;
+
 # use warnings;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $LogEvals);
 
@@ -10,7 +11,7 @@ require Exporter;
 @EXPORT    = qw( confess carp croak );
 @EXPORT_OK = qw( cluck click register_source );
 
-$VERSION   = '1.39';
+$VERSION = '1.40';
 
 require Carp;
 require Carp::Heavy;
@@ -23,31 +24,29 @@ use Win32::EventLog qw(
   EVENTLOG_AUDIT_SUCCESS EVENTLOG_AUDIT_FAILURE
 );
 
-my ($EventLogHandle, $Source, $SourceFileName, $Register);
+my ( $EventLogHandle, $Source, $SourceFileName, $Register );
 
 # We want to provide options on the 'use Win32::EventLog::Carp' line
 
-sub import
-  {
+sub import {
     my $package = shift;
 
     my @exports = grep { "HASH" ne ref($_) } @_;
     my @options = grep { "HASH" eq ref($_) } @_;
 
-    foreach (@options)
-      {
-	$Source    = $_->{Source};   # Source name (defaults to script name)
-        $LogEvals  = $_->{LogEvals}; # Do we log evals when they fail?
-        $Register  = $_->{Register}; # Should we register the source?
-      }
-
-    if ($Register) {
-      register_source( $Register, $Source );
+    foreach (@options) {
+        $Source   = $_->{Source};      # Source name (defaults to script name)
+        $LogEvals = $_->{LogEvals};    # Do we log evals when they fail?
+        $Register = $_->{Register};    # Should we register the source?
     }
 
-    @_ = ($package, @exports);
+    if ($Register) {
+        register_source( $Register, $Source );
+    }
+
+    @_ = ( $package, @exports );
     goto &Exporter::import;
-  }
+}
 
 sub register_source
 
@@ -58,218 +57,208 @@ sub register_source
 
   # Needs to check if a log is created, and if so, close it and then reopen it.
 
-  {
-    my ($log_name, $source_name) = @_;
+{
+    my ( $log_name, $source_name ) = @_;
 
     # Really what we need to do is to check if the source is registered
     # first...
 
-    my $aux = $LogEvals; $LogEvals = 0;  # save LogEvals
+    my $aux = $LogEvals;
+    $LogEvals = 0;    # save LogEvals
     eval {
-      require Win32::EventLog::Message;
-      import Win32::EventLog::Message;
-      Win32::EventLog::Message::RegisterSource( $log_name, $source_name );
+        require Win32::EventLog::Message;
+        import Win32::EventLog::Message;
+        Win32::EventLog::Message::RegisterSource( $log_name, $source_name );
     };
-    $LogEvals = $aux;                   # restore LogEvals
+    $LogEvals = $aux;    # restore LogEvals
 
     if ($@) {
-      CORE::warn "Unable to register source \`$source_name\' in \`$log_name\' log";
+        CORE::warn
+          "Unable to register source \`$source_name\' in \`$log_name\' log";
     }
-  }
+}
 
 sub _report
 
-# Reports an event in the Windows NT event log.
+  # Reports an event in the Windows NT event log.
 
-  {
-    unless ($EventLogHandle)
-      {
-	# Create a handle to the Windows NT event log (we do this in the BEGIN
-	# block so that we can trap some compilation errors).
+{
+    unless ($EventLogHandle) {
 
-	my $log = ($Register) ? $Source : "Application";
+        # Create a handle to the Windows NT event log (we do this in the BEGIN
+        # block so that we can trap some compilation errors).
 
-	$EventLogHandle = Win32::EventLog->new( $log, Win32::NodeName )
-	  or CORE::die "Unable to initialize Windows NT event log";
+        my $log = ($Register) ? $Source : "Application";
 
-      }
+        $EventLogHandle = Win32::EventLog->new( $log, Win32::NodeName )
+          or CORE::die "Unable to initialize Windows NT event log";
+
+    }
 
     # If for some reason the log isn't initialized...!
 
-    unless (defined $EventLogHandle)
-      {
-	CORE::die
-	  "Win32::EventLog not initialized in Win32::EventLog::Carp";
-	return;
-      }
+    unless ( defined $EventLogHandle ) {
+        CORE::die "Win32::EventLog not initialized in Win32::EventLog::Carp";
+        return;
+    }
 
-    my ($event_type, $event_text) = @_;
+    my ( $event_type, $event_text ) = @_;
 
-    unless ((defined $event_text) && (defined $event_type)) {
-      return; }
+    unless ( ( defined $event_text ) && ( defined $event_type ) ) {
+        return;
+    }
 
     # If we're posting to the security log, convert the event types to
     # ones associated with the security log. (In reality, Windows
     # doesn't seem to care, but we want to play nice...)
 
-    if (($Register||"") eq "Security") {
-      if ($event_type == EVENTLOG_INFORMATION_TYPE) {
-	$event_type = EVENTLOG_AUDIT_SUCCESS;
-      }
-      else {
-	$event_type = EVENTLOG_AUDIT_FAILURE;
-      }
+    if ( ( $Register || "" ) eq "Security" ) {
+        if ( $event_type == EVENTLOG_INFORMATION_TYPE ) {
+            $event_type = EVENTLOG_AUDIT_SUCCESS;
+        }
+        else {
+            $event_type = EVENTLOG_AUDIT_FAILURE;
+        }
     }
 
     # Change newlines to semicolons ('; ') since they do not show up well in
     # the event log viewer (does Windows 2000 handle newlines better?)
 
-    $event_text = join(": ", $SourceFileName, $event_text);
+    $event_text = join( ": ", $SourceFileName, $event_text );
 
-#     $event_text =~ s/\x0/; /g;                # only one string is used
+    #     $event_text =~ s/\x0/; /g;                # only one string is used
     $event_text =~ s/(\r?\n){1,}(?!\z)/\; /g;
     $event_text =~ s/\r?\n\z//;
 
     my $event = {
-                 Computer  => Win32::NodeName,
-                 Source    => $Source,
-		 EventID   => 0,
-                 Category  => 0,
-		 EventType => $event_type,
-		 Strings   => $event_text,
-                 Data      => "",
-		};
+        Computer  => Win32::NodeName,
+        Source    => $Source,
+        EventID   => 0,
+        Category  => 0,
+        EventType => $event_type,
+        Strings   => $event_text,
+        Data      => "",
+    };
 
-    $EventLogHandle->Report( $event );
-  }
+    $EventLogHandle->Report($event);
+}
 
 # Test to see if we're in an eval { }
 
-sub _ineval
-  {
-    if ($LogEvals) # If $LogEvals is true, lie and say we're never in an eval
-      {
-	return;
-      }
-    else            # Otherwise actually do a test
-      {
-	# This test is based on the one used in CGI::Carp v1.20
-	return (Carp::longmess(@_) =~ /eval [\'\{]/m)
-      }
-  }
+sub _ineval {
+    if ($LogEvals)    # If $LogEvals is true, lie and say we're never in an eval
+    {
+        return;
+    }
+    else              # Otherwise actually do a test
+    {
+
+        # This test is based on the one used in CGI::Carp v1.20
+        return ( Carp::longmess(@_) =~ /eval [\'\{]/m );
+    }
+}
 
 # Our own verson of "warn"
 
-sub _warn
-  {
+sub _warn {
     _report( EVENTLOG_WARNING_TYPE, @_ );
     CORE::warn @_;
-  }
+}
 
 # Our own version of "die"
 
-sub _die
-  {
-    unless (_ineval @_) # don't log it if we're in an eval
-      {
-	_report( EVENTLOG_ERROR_TYPE, @_ );
-      }
-    CORE::die @_; 
-  }
+sub _die {
+    unless ( _ineval @_ )    # don't log it if we're in an eval
+    {
+        _report( EVENTLOG_ERROR_TYPE, @_ );
+    }
+    CORE::die @_;
+}
 
+BEGIN {
 
-BEGIN
-  {
     # These are hooks for defining our own Source and Log
 
-    $SourceFileName = File::Spec->rel2abs( $0 );
+    $SourceFileName = File::Spec->rel2abs($0);
 
-    unless ($Source)
-      {
+    unless ($Source) {
 
-	# We use the basename of the file because registry keys cannot have
-	# slashes in them. Of course since we are registering an event source
-	# (only if we have admin privs) we'll include the full patch in the
-	# event text (after all, an error in 'index.pl' doesn't tell us which
-	# one).
+        # We use the basename of the file because registry keys cannot have
+        # slashes in them. Of course since we are registering an event source
+        # (only if we have admin privs) we'll include the full patch in the
+        # event text (after all, an error in 'index.pl' doesn't tell us which
+        # one).
 
-	$Source =  File::Basename::basename( $SourceFileName );
-      }
+        $Source = File::Basename::basename($SourceFileName);
+    }
 
     # If there's already a handler, we just report the error to the log and
     # go to the existing handler (so we assume the other handler does what
     # it should); otherwise we use our own.
 
-    if ($SIG{__WARN__})
-      {
-	my $previous = $SIG{__WARN__};
-	$SIG{__WARN__} = sub {
-	  _report( EVENTLOG_WARNING_TYPE, @_ );
-	  return &$previous;
-	};
-      }
-    else
-      {
-	$SIG{__WARN__} = \&Win32::EventLog::Carp::_warn;
-      }
+    if ( $SIG{__WARN__} ) {
+        my $previous = $SIG{__WARN__};
+        $SIG{__WARN__} = sub {
+            _report( EVENTLOG_WARNING_TYPE, @_ );
+            return &$previous;
+        };
+    }
+    else {
+        $SIG{__WARN__} = \&Win32::EventLog::Carp::_warn;
+    }
 
     # Likewise for "die", we put ourselves between an existing signal handler
     # rather than take it over.
 
-    if ($SIG{__DIE__})
-      {
-	my $previous = $SIG{__DIE__};
-	$SIG{__DIE__} = sub {
-	  unless (_ineval(@_)) {
-	    _report( EVENTLOG_ERROR_TYPE, @_ );
-	  }
-	  return &$previous;
-	};
-      }
-    else
-      {
-	$SIG{__DIE__} = \&Win32::EventLog::Carp::_die;
-      }
+    if ( $SIG{__DIE__} ) {
+        my $previous = $SIG{__DIE__};
+        $SIG{__DIE__} = sub {
+            unless ( _ineval(@_) ) {
+                _report( EVENTLOG_ERROR_TYPE, @_ );
+            }
+            return &$previous;
+        };
+    }
+    else {
+        $SIG{__DIE__} = \&Win32::EventLog::Carp::_die;
+    }
 
-  }
+}
 
 # Close the event log.
 
-sub _closelog()
-  {
-    if ($EventLogHandle)
-      {
- 	$EventLogHandle->Close();
-	$EventLogHandle = undef;
-      }
-  }
+sub _closelog() {
+    if ($EventLogHandle) {
+        $EventLogHandle->Close();
+        $EventLogHandle = undef;
+    }
+}
+
+END {
 
-END
-  {
     # Make sure we clean up after ourselves!
     _closelog();
-  }
+}
 
 # Our own versions of Carp's functions ... we piggyback on Carp's special
 # "longmess" and shortmess" functions. (According to some discussion on
 # the Perl 5 Porters list in July 2001 these may be renamed to "yodel" and
 # "yelp", but with aliases for the old names. Don't panic.)
 
-sub carp    { CORE::warn Carp::shortmess @_;    }
-sub croak   { CORE::die  Carp::shortmess @_;   }
-sub cluck   { CORE::warn Carp::longmess @_;   }
-sub confess { CORE::die  Carp::longmess @_; }
+sub carp    { CORE::warn Carp::shortmess @_; }
+sub croak   { CORE::die Carp::shortmess @_; }
+sub cluck   { CORE::warn Carp::longmess @_; }
+sub confess { CORE::die Carp::longmess @_; }
 
 # Since posting diagnostic (non-warning/error) messages into the event log
 # is useful, why not a function that simply reports to the log and STDERR
 # without being considered an error? Hence, "click".
 
-sub click
-  {
+sub click {
     my $message = Carp::shortmess(@_);
     &_report( EVENTLOG_INFORMATION_TYPE, $message );
     print STDERR $message;
-  }
+}
 
 1;
 __END__
@@ -278,6 +267,11 @@ __END__
 
 Win32::EventLog::Carp - for carping in the Windows NT Event Log
 
+=head1 BERSION
+
+This document describes version 1.40 of Win32::EventLog::Carp, released
+2006-10-06.
+
 =head1 REQUIREMENTS
 
   Carp
@@ -310,8 +304,7 @@ One notable exception is the addition of the C<click> function:
 
   Win32::EventLog::Carp::click "Hello!\n";
 
-This outouts a message to F<STDERR1
-> with a short stack trace and allows scripts
+This outouts a message to F<STDERR> with a short stack trace and allows scripts
 to post a simple "I have started" or "I am doing XYZ now" message to the log.
 To avoid the stack trace, end the message with a newline (which is what
 happens with the C<Carp> module).
@@ -348,8 +341,8 @@ C<LogEvals> option:
 
   use Win32::EventLog::Carp
         {
-	  LogEvals => 1
-	};
+          LogEvals => 1
+        };
 
 You can also change the value from within your program:
 
@@ -381,7 +374,7 @@ You can specify a different event source. The following
   use Win32::EventLog::Carp qw(cluck carp croak click confess),
         {
           Source => 'MyProject'
-	};
+        };
 
 will list the source as "MyProject" rather than the filename.
 
@@ -390,10 +383,10 @@ will list the source as "MyProject" rather than the filename.
 You can specify a log other than the Application Log to report events
 to:
 
-  use Win32::EventLog::Carp 1.36
+  use Win32::EventLog::Carp 1.40
         {
           Register => 'System'
-	};
+        };
 
 Events can only be posted to one log.  (For example, you cannot have
 some events go to the Application Log while others go to the Security
@@ -488,6 +481,8 @@ L<http://stonybrook.pm.org/>
 
 =head1 AUTHOR
 
+David Landgren <dland at cpan.org> (current maintainer)
+
 Robert Rothenberg <rrwo at cpan.org>
 
 =head2 Suggestions and Bug Reporting
@@ -497,7 +492,8 @@ L<http://rt.cpan.org> to submit bug reports.
 
 =head1 LICENSE
 
-Copyright (c) 2000-2004, Robert Rothenberg. All rights reserved.
+Copyright (c) 2000-2004, Robert Rothenberg. Copyright (c) 2006,
+David Landgren. All rights reserved.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
